/* See LICENSE file for copyright and license details. */
#include <X11/XF86keysym.h>

/* appearance */
static const unsigned int borderpx  = 2;        /* border pixel of windows */
static const Gap default_gap        = {.isgap = 1, .realgap = 25, .gappx = 25};
static const unsigned int snap      = 15;       /* snap pixel */
static const int swallowfloating    = 0;        /* 1 means swallow floating windows by default */
static const int showbar            = 1;        /* 0 means no bar */
static const int topbar             = 0;        /* 0 means bottom bar */
static const char *fonts[]          = { "SourceCodePro:size=9" };
static const char dmenufont[]       = "SourceCodePro:size=9";
static const char col_gray1[]       = "#222222";
static const char col_gray2[]       = "#444444";
static const char col_gray3[]       = "#bbbbbb";
static const char col_gray4[]       = "#eeeeee";
static const char col_cyan[]        = "#005577";
/* custom colors */
static const char col_aqua[]        = "#83a598";
static const char col_ggrey[]       = "#121212";
static const char *colors[][3]      = {
/* --------------- */
	/*               fg         bg         border   */
	[SchemeNorm] = { col_aqua,  col_ggrey, col_ggrey },
	[SchemeSel]  = { col_ggrey, col_aqua,  col_aqua  },
};

/* tagging */
static const char *tags[] = { "   I   ", "   II   ", "   III   ", "   IV   ", "   V   " };

static const Rule rules[] = {
	/* xprop(1):
	 *	WM_CLASS(STRING) = instance, class
	 *	WM_NAME(STRING) = title
	 */
	/* class     instance  title           tags mask  isfloating  isterminal  noswallow  monitor */
	{ "st",      NULL,     NULL,           0,         0,          1,           0,        -1 },
	{ NULL,      NULL,     "Event Tester", 0,         0,          0,           1,        -1 }, /* xev */
};

/* layout(s) */
static const float mfact     = 0.55; /* factor of master area size [0.05..0.95] */
static const int nmaster     = 1;    /* number of clients in master area */
static const int resizehints = 1;    /* 1 means respect size hints in tiled resizals */
static const int lockfullscreen = 0; /* 1 will force focus on the fullscreen window */

static const Layout layouts[] = {
	/* symbol     arrange function */
	{ "",      tile },    /* first entry is default */
	{ "[M]",      monocle },
};

/* key definitions */
#define MODKEY Mod4Mask
#define TAGKEYS(KEY,TAG) \
	{ MODKEY,                       KEY,      view,           {.ui = 1 << TAG} }, \
	{ MODKEY|ControlMask,           KEY,      toggleview,     {.ui = 1 << TAG} }, \
	{ MODKEY|ShiftMask,             KEY,      tag,            {.ui = 1 << TAG} }, \
	{ MODKEY|ControlMask|ShiftMask, KEY,      toggletag,      {.ui = 1 << TAG} },

/* helper for spawning shell commands in the pre dwm-5.0 fashion */
#define SHCMD(cmd) { .v = (const char*[]){ "/bin/sh", "-c", cmd, NULL } }

#define STATUSBAR "dwmblocks"

/* commands */
static const char *dmenucmd[]       = { "dmenu_run", "-i", "-p", "Run:", NULL };
static const char *termcmd[]  = { "st", NULL };
/* custom commands */
static const char *filemanager[]    = { "st", "-e", "nnn", "-H", NULL };
static const char *dbookmarks[]     = { "dmenu-bookmarks", "-i", NULL };
static const char *dexec[]          = { "dmenu-scripts", "-i", NULL };
static const char *dpass[]          = { "dmenu-pass", "-i", NULL };
static const char *dpassotp[]       = { "dmenu-otp", "-i", NULL };
static const char *dlayout[]        = { "dmenu-layout", NULL };
static const char *doutput[]        = { "dmenu-output", NULL };
static const char *dinput[]         = { "dmenu-input", NULL };
static const char *dpower[]         = { "dmenu-power", NULL };
static const char *browser[]        = { "tabbed-surf", NULL };
static const char *iwctlscan[]      = { "iwctl-scan", NULL };
static const char *brightdown[]     = { "brightdown", NULL };
static const char *brightup[]       = { "brightup", NULL };
static const char *clipmenu[]       = { "clipmenu", NULL };
static const char *voldown[]        = { "voldown", NULL };
static const char *volup[]          = { "volup", NULL };
static const char *prtsc[]          = { "prtsc", NULL };
static const char *mute[]           = { "mute", NULL };
/* --------------- */

#include "movestack.c"
static const Key keys[] = {
	/* modifier                     key        function        argument */
	{ MODKEY,                       XK_r,      spawn,          {.v = dmenucmd } },
	{ MODKEY,                       XK_Return, spawn,          {.v = termcmd } },
	{ MODKEY|ShiftMask,             XK_b,      togglebar,      {0} },
	{ MODKEY,                       XK_j,      focusstack,     {.i = +1 } },
	{ MODKEY,                       XK_k,      focusstack,     {.i = -1 } },
	{ MODKEY|ShiftMask,             XK_i,      incnmaster,     {.i = +1 } },
	{ MODKEY|ShiftMask,             XK_d,      incnmaster,     {.i = -1 } },
	{ MODKEY,                       XK_h,      setmfact,       {.f = -0.05} },
	{ MODKEY,                       XK_l,      setmfact,       {.f = +0.05} },
	{ MODKEY|ShiftMask,             XK_j,      movestack,      {.i = +1 } },
	{ MODKEY|ShiftMask,             XK_k,      movestack,      {.i = -1 } },
	{ MODKEY|ShiftMask,             XK_Return, zoom,           {0} },
	{ MODKEY,                       XK_Tab,    view,           {0} },
	{ MODKEY,                       XK_c,      killclient,     {0} },
	{ MODKEY|ShiftMask,             XK_t,      setlayout,      {.v = &layouts[0]} },
	{ MODKEY|ShiftMask,             XK_m,      setlayout,      {.v = &layouts[1]} },
	{ MODKEY,                       XK_t,      togglefloating, {0} },
	{ MODKEY,                       XK_s,      togglesticky,   {0} },
	{ MODKEY,                       XK_0,      view,           {.ui = ~0 } },
	{ MODKEY|ShiftMask,             XK_0,      tag,            {.ui = ~0 } },
	{ MODKEY,                       XK_comma,  focusmon,       {.i = -1 } },
	{ MODKEY,                       XK_period, focusmon,       {.i = +1 } },
	{ MODKEY|ShiftMask,             XK_comma,  tagmon,         {.i = -1 } },
	{ MODKEY|ShiftMask,             XK_period, tagmon,         {.i = +1 } },
	{ MODKEY,                       XK_minus,  setgaps,        {.i = -5 } },
	{ MODKEY,                       XK_equal,  setgaps,        {.i = +5 } },
	{ MODKEY|ShiftMask,             XK_minus,  setgaps,        {.i = GAP_RESET } },
	{ MODKEY|ShiftMask,             XK_equal,  setgaps,        {.i = GAP_TOGGLE} },
	TAGKEYS(                        XK_1,                      0)
	TAGKEYS(                        XK_2,                      1)
	TAGKEYS(                        XK_3,                      2)
	TAGKEYS(                        XK_4,                      3)
	TAGKEYS(                        XK_5,                      4)
	{ MODKEY|ShiftMask,             XK_q,      quit,           {0} },
    /* custom binds */
	{ MODKEY,                       XK_f,      spawn,          {.v = filemanager } },
	{ MODKEY,                       XK_b,      spawn,          {.v = dbookmarks } },
	{ MODKEY|ShiftMask,             XK_w,      spawn,          {.v = iwctlscan } },
	{ MODKEY|ShiftMask,             XK_o,      spawn,          {.v = dpassotp } },
	{ MODKEY|ShiftMask,             XK_c,      spawn,          {.v = clipmenu } },
	{ MODKEY,                       XK_w,      spawn,          {.v = browser } },
	{ MODKEY,                       XK_o,      spawn,          {.v = doutput } },
	{ MODKEY,                       XK_space,  spawn,          {.v = dlayout } },
	{ MODKEY,                       XK_p,      spawn,          {.v = dpower } },
	{ MODKEY,                       XK_i,      spawn,          {.v = dinput } },
	{ MODKEY|ShiftMask,             XK_p,      spawn,          {.v = dpass } },
	{ MODKEY,                       XK_e,      spawn,          {.v = dexec} },
	{ 0,             XF86XK_MonBrightnessDown, spawn,          {.v = brightdown } },
	{ 0,             XF86XK_MonBrightnessUp,   spawn,          {.v = brightup } },
	{ 0,             XF86XK_AudioLowerVolume,  spawn,          {.v = voldown } },
	{ 0,             XF86XK_AudioRaiseVolume,  spawn,          {.v = volup } },
	{ 0,             XK_Print,                 spawn,          {.v = prtsc } },
	{ 0,             XF86XK_AudioMute,         spawn,          {.v = mute } },
    /* ------------ */
};

/* button definitions */
/* click can be ClkTagBar, ClkLtSymbol, ClkStatusText, ClkWinTitle, ClkClientWin, or ClkRootWin */
static const Button buttons[] = {
	/* click                event mask      button          function        argument */
	{ ClkStatusText,        0,              Button2,        spawn,          {.v = termcmd } },
	{ ClkClientWin,         MODKEY,         Button1,        movemouse,      {0} },
	{ ClkClientWin,         MODKEY,         Button2,        togglefloating, {0} },
	{ ClkClientWin,         MODKEY,         Button3,        resizemouse,    {0} },
	{ ClkTagBar,            0,              Button1,        view,           {0} },
	{ ClkTagBar,            0,              Button3,        toggleview,     {0} },
	{ ClkTagBar,            MODKEY,         Button1,        tag,            {0} },
	{ ClkTagBar,            MODKEY,         Button3,        toggletag,      {0} },
};

